# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ReviewArgs', 'Review']

@pulumi.input_type
class ReviewArgs:
    def __init__(__self__, *,
                 campaign_id: pulumi.Input[_builtins.str],
                 note: pulumi.Input[_builtins.str],
                 review_ids: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 reviewer_id: pulumi.Input[_builtins.str],
                 reviewer_level: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Review resource.
        :param pulumi.Input[_builtins.str] campaign_id: The id of the campaign.
        :param pulumi.Input[_builtins.str] note: A note to justify the reassignment decision for the specified review.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] review_ids: A list of reviews (review id values) that are reassigned to the new reviewer.
        :param pulumi.Input[_builtins.str] reviewer_id: The Okta user id of the new reviewer.
        :param pulumi.Input[_builtins.str] reviewer_level: Identifies the reviewer level of each reviews during access certification. Applicable for multi level campaigns only.
        """
        pulumi.set(__self__, "campaign_id", campaign_id)
        pulumi.set(__self__, "note", note)
        pulumi.set(__self__, "review_ids", review_ids)
        pulumi.set(__self__, "reviewer_id", reviewer_id)
        if reviewer_level is not None:
            pulumi.set(__self__, "reviewer_level", reviewer_level)

    @_builtins.property
    @pulumi.getter(name="campaignId")
    def campaign_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the campaign.
        """
        return pulumi.get(self, "campaign_id")

    @campaign_id.setter
    def campaign_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "campaign_id", value)

    @_builtins.property
    @pulumi.getter
    def note(self) -> pulumi.Input[_builtins.str]:
        """
        A note to justify the reassignment decision for the specified review.
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "note", value)

    @_builtins.property
    @pulumi.getter(name="reviewIds")
    def review_ids(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        A list of reviews (review id values) that are reassigned to the new reviewer.
        """
        return pulumi.get(self, "review_ids")

    @review_ids.setter
    def review_ids(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "review_ids", value)

    @_builtins.property
    @pulumi.getter(name="reviewerId")
    def reviewer_id(self) -> pulumi.Input[_builtins.str]:
        """
        The Okta user id of the new reviewer.
        """
        return pulumi.get(self, "reviewer_id")

    @reviewer_id.setter
    def reviewer_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "reviewer_id", value)

    @_builtins.property
    @pulumi.getter(name="reviewerLevel")
    def reviewer_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifies the reviewer level of each reviews during access certification. Applicable for multi level campaigns only.
        """
        return pulumi.get(self, "reviewer_level")

    @reviewer_level.setter
    def reviewer_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reviewer_level", value)


@pulumi.input_type
class _ReviewState:
    def __init__(__self__, *,
                 campaign_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 decision: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 review_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 reviewer_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reviewer_level: Optional[pulumi.Input[_builtins.str]] = None,
                 reviewer_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Review resources.
        :param pulumi.Input[_builtins.str] campaign_id: The id of the campaign.
        :param pulumi.Input[_builtins.str] created: The ISO 8601 formatted date and time when the resource was created
        :param pulumi.Input[_builtins.str] created_by: The id of user who created the resource.
        :param pulumi.Input[_builtins.str] decision: The decision of the reviewer.
        :param pulumi.Input[_builtins.str] last_updated: The ISO 8601 formatted date and time when the object was last updated.
        :param pulumi.Input[_builtins.str] last_updated_by: The id of user who last updated the object.
        :param pulumi.Input[_builtins.str] note: A note to justify the reassignment decision for the specified review.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] review_ids: A list of reviews (review id values) that are reassigned to the new reviewer.
        :param pulumi.Input[_builtins.str] reviewer_id: The Okta user id of the new reviewer.
        :param pulumi.Input[_builtins.str] reviewer_level: Identifies the reviewer level of each reviews during access certification. Applicable for multi level campaigns only.
        :param pulumi.Input[_builtins.str] reviewer_type: The type of reviewer to which the review is assigned.
        """
        if campaign_id is not None:
            pulumi.set(__self__, "campaign_id", campaign_id)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if decision is not None:
            pulumi.set(__self__, "decision", decision)
        if last_updated is not None:
            pulumi.set(__self__, "last_updated", last_updated)
        if last_updated_by is not None:
            pulumi.set(__self__, "last_updated_by", last_updated_by)
        if note is not None:
            pulumi.set(__self__, "note", note)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if review_ids is not None:
            pulumi.set(__self__, "review_ids", review_ids)
        if reviewer_id is not None:
            pulumi.set(__self__, "reviewer_id", reviewer_id)
        if reviewer_level is not None:
            pulumi.set(__self__, "reviewer_level", reviewer_level)
        if reviewer_type is not None:
            pulumi.set(__self__, "reviewer_type", reviewer_type)

    @_builtins.property
    @pulumi.getter(name="campaignId")
    def campaign_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the campaign.
        """
        return pulumi.get(self, "campaign_id")

    @campaign_id.setter
    def campaign_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "campaign_id", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ISO 8601 formatted date and time when the resource was created
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of user who created the resource.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter
    def decision(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The decision of the reviewer.
        """
        return pulumi.get(self, "decision")

    @decision.setter
    def decision(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "decision", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ISO 8601 formatted date and time when the object was last updated.
        """
        return pulumi.get(self, "last_updated")

    @last_updated.setter
    def last_updated(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of user who last updated the object.
        """
        return pulumi.get(self, "last_updated_by")

    @last_updated_by.setter
    def last_updated_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated_by", value)

    @_builtins.property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A note to justify the reassignment decision for the specified review.
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "note", value)

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_id", value)

    @_builtins.property
    @pulumi.getter(name="reviewIds")
    def review_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of reviews (review id values) that are reassigned to the new reviewer.
        """
        return pulumi.get(self, "review_ids")

    @review_ids.setter
    def review_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "review_ids", value)

    @_builtins.property
    @pulumi.getter(name="reviewerId")
    def reviewer_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Okta user id of the new reviewer.
        """
        return pulumi.get(self, "reviewer_id")

    @reviewer_id.setter
    def reviewer_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reviewer_id", value)

    @_builtins.property
    @pulumi.getter(name="reviewerLevel")
    def reviewer_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifies the reviewer level of each reviews during access certification. Applicable for multi level campaigns only.
        """
        return pulumi.get(self, "reviewer_level")

    @reviewer_level.setter
    def reviewer_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reviewer_level", value)

    @_builtins.property
    @pulumi.getter(name="reviewerType")
    def reviewer_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of reviewer to which the review is assigned.
        """
        return pulumi.get(self, "reviewer_type")

    @reviewer_type.setter
    def reviewer_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reviewer_type", value)


@pulumi.type_token("okta:index/review:Review")
class Review(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 campaign_id: Optional[pulumi.Input[_builtins.str]] = None,
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 review_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 reviewer_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reviewer_level: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages reassignment of review.

        This resource allows you to reassign an already existing review.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.Review("test",
            campaign_id="icizigd86iM9sOcbN1d6",
            reviewer_id="00unli90kor62oF5Z1d7",
            review_ids=["icrztblxbBFiVKepb1d6"],
            reviewer_level="FIRST",
            note="John Smith is on leave for this month. His manager Tim will be the reviewer instead.")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/review:Review example <review_id?
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] campaign_id: The id of the campaign.
        :param pulumi.Input[_builtins.str] note: A note to justify the reassignment decision for the specified review.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] review_ids: A list of reviews (review id values) that are reassigned to the new reviewer.
        :param pulumi.Input[_builtins.str] reviewer_id: The Okta user id of the new reviewer.
        :param pulumi.Input[_builtins.str] reviewer_level: Identifies the reviewer level of each reviews during access certification. Applicable for multi level campaigns only.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ReviewArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages reassignment of review.

        This resource allows you to reassign an already existing review.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.Review("test",
            campaign_id="icizigd86iM9sOcbN1d6",
            reviewer_id="00unli90kor62oF5Z1d7",
            review_ids=["icrztblxbBFiVKepb1d6"],
            reviewer_level="FIRST",
            note="John Smith is on leave for this month. His manager Tim will be the reviewer instead.")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/review:Review example <review_id?
        ```

        :param str resource_name: The name of the resource.
        :param ReviewArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ReviewArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 campaign_id: Optional[pulumi.Input[_builtins.str]] = None,
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 review_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 reviewer_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reviewer_level: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ReviewArgs.__new__(ReviewArgs)

            if campaign_id is None and not opts.urn:
                raise TypeError("Missing required property 'campaign_id'")
            __props__.__dict__["campaign_id"] = campaign_id
            if note is None and not opts.urn:
                raise TypeError("Missing required property 'note'")
            __props__.__dict__["note"] = note
            if review_ids is None and not opts.urn:
                raise TypeError("Missing required property 'review_ids'")
            __props__.__dict__["review_ids"] = review_ids
            if reviewer_id is None and not opts.urn:
                raise TypeError("Missing required property 'reviewer_id'")
            __props__.__dict__["reviewer_id"] = reviewer_id
            __props__.__dict__["reviewer_level"] = reviewer_level
            __props__.__dict__["created"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["decision"] = None
            __props__.__dict__["last_updated"] = None
            __props__.__dict__["last_updated_by"] = None
            __props__.__dict__["resource_id"] = None
            __props__.__dict__["reviewer_type"] = None
        super(Review, __self__).__init__(
            'okta:index/review:Review',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            campaign_id: Optional[pulumi.Input[_builtins.str]] = None,
            created: Optional[pulumi.Input[_builtins.str]] = None,
            created_by: Optional[pulumi.Input[_builtins.str]] = None,
            decision: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
            note: Optional[pulumi.Input[_builtins.str]] = None,
            resource_id: Optional[pulumi.Input[_builtins.str]] = None,
            review_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            reviewer_id: Optional[pulumi.Input[_builtins.str]] = None,
            reviewer_level: Optional[pulumi.Input[_builtins.str]] = None,
            reviewer_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Review':
        """
        Get an existing Review resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] campaign_id: The id of the campaign.
        :param pulumi.Input[_builtins.str] created: The ISO 8601 formatted date and time when the resource was created
        :param pulumi.Input[_builtins.str] created_by: The id of user who created the resource.
        :param pulumi.Input[_builtins.str] decision: The decision of the reviewer.
        :param pulumi.Input[_builtins.str] last_updated: The ISO 8601 formatted date and time when the object was last updated.
        :param pulumi.Input[_builtins.str] last_updated_by: The id of user who last updated the object.
        :param pulumi.Input[_builtins.str] note: A note to justify the reassignment decision for the specified review.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] review_ids: A list of reviews (review id values) that are reassigned to the new reviewer.
        :param pulumi.Input[_builtins.str] reviewer_id: The Okta user id of the new reviewer.
        :param pulumi.Input[_builtins.str] reviewer_level: Identifies the reviewer level of each reviews during access certification. Applicable for multi level campaigns only.
        :param pulumi.Input[_builtins.str] reviewer_type: The type of reviewer to which the review is assigned.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ReviewState.__new__(_ReviewState)

        __props__.__dict__["campaign_id"] = campaign_id
        __props__.__dict__["created"] = created
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["decision"] = decision
        __props__.__dict__["last_updated"] = last_updated
        __props__.__dict__["last_updated_by"] = last_updated_by
        __props__.__dict__["note"] = note
        __props__.__dict__["resource_id"] = resource_id
        __props__.__dict__["review_ids"] = review_ids
        __props__.__dict__["reviewer_id"] = reviewer_id
        __props__.__dict__["reviewer_level"] = reviewer_level
        __props__.__dict__["reviewer_type"] = reviewer_type
        return Review(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="campaignId")
    def campaign_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the campaign.
        """
        return pulumi.get(self, "campaign_id")

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.str]:
        """
        The ISO 8601 formatted date and time when the resource was created
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.str]:
        """
        The id of user who created the resource.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def decision(self) -> pulumi.Output[_builtins.str]:
        """
        The decision of the reviewer.
        """
        return pulumi.get(self, "decision")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> pulumi.Output[_builtins.str]:
        """
        The ISO 8601 formatted date and time when the object was last updated.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> pulumi.Output[_builtins.str]:
        """
        The id of user who last updated the object.
        """
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter
    def note(self) -> pulumi.Output[_builtins.str]:
        """
        A note to justify the reassignment decision for the specified review.
        """
        return pulumi.get(self, "note")

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "resource_id")

    @_builtins.property
    @pulumi.getter(name="reviewIds")
    def review_ids(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of reviews (review id values) that are reassigned to the new reviewer.
        """
        return pulumi.get(self, "review_ids")

    @_builtins.property
    @pulumi.getter(name="reviewerId")
    def reviewer_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Okta user id of the new reviewer.
        """
        return pulumi.get(self, "reviewer_id")

    @_builtins.property
    @pulumi.getter(name="reviewerLevel")
    def reviewer_level(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Identifies the reviewer level of each reviews during access certification. Applicable for multi level campaigns only.
        """
        return pulumi.get(self, "reviewer_level")

    @_builtins.property
    @pulumi.getter(name="reviewerType")
    def reviewer_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of reviewer to which the review is assigned.
        """
        return pulumi.get(self, "reviewer_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserBaseSchemaPropertyArgs', 'UserBaseSchemaProperty']

@pulumi.input_type
class UserBaseSchemaPropertyArgs:
    def __init__(__self__, *,
                 index: pulumi.Input[_builtins.str],
                 title: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 master: Optional[pulumi.Input[_builtins.str]] = None,
                 pattern: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[_builtins.str]] = None,
                 required: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a UserBaseSchemaProperty resource.
        :param pulumi.Input[_builtins.str] index: Subschema unique string identifier
        :param pulumi.Input[_builtins.str] title: Subschema title (display name)
        :param pulumi.Input[_builtins.str] type: The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        :param pulumi.Input[_builtins.str] master: Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`. Default: `PROFILE_MASTER`
        :param pulumi.Input[_builtins.str] pattern: The validation pattern to use for the subschema. Must be in form of '.+', or '[\\n\\n]+' if present.'
        :param pulumi.Input[_builtins.str] permissions: Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        :param pulumi.Input[_builtins.bool] required: Whether the subschema is required
        :param pulumi.Input[_builtins.str] user_type: User type ID. By default, it is `default`
        """
        pulumi.set(__self__, "index", index)
        pulumi.set(__self__, "title", title)
        pulumi.set(__self__, "type", type)
        if master is not None:
            pulumi.set(__self__, "master", master)
        if pattern is not None:
            pulumi.set(__self__, "pattern", pattern)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if required is not None:
            pulumi.set(__self__, "required", required)
        if user_type is not None:
            pulumi.set(__self__, "user_type", user_type)

    @_builtins.property
    @pulumi.getter
    def index(self) -> pulumi.Input[_builtins.str]:
        """
        Subschema unique string identifier
        """
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "index", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Input[_builtins.str]:
        """
        Subschema title (display name)
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "title", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def master(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`. Default: `PROFILE_MASTER`
        """
        return pulumi.get(self, "master")

    @master.setter
    def master(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "master", value)

    @_builtins.property
    @pulumi.getter
    def pattern(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The validation pattern to use for the subschema. Must be in form of '.+', or '[\\n\\n]+' if present.'
        """
        return pulumi.get(self, "pattern")

    @pattern.setter
    def pattern(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pattern", value)

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "permissions", value)

    @_builtins.property
    @pulumi.getter
    def required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the subschema is required
        """
        return pulumi.get(self, "required")

    @required.setter
    def required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "required", value)

    @_builtins.property
    @pulumi.getter(name="userType")
    def user_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User type ID. By default, it is `default`
        """
        return pulumi.get(self, "user_type")

    @user_type.setter
    def user_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_type", value)


@pulumi.input_type
class _UserBaseSchemaPropertyState:
    def __init__(__self__, *,
                 index: Optional[pulumi.Input[_builtins.str]] = None,
                 master: Optional[pulumi.Input[_builtins.str]] = None,
                 pattern: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[_builtins.str]] = None,
                 required: Optional[pulumi.Input[_builtins.bool]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 user_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering UserBaseSchemaProperty resources.
        :param pulumi.Input[_builtins.str] index: Subschema unique string identifier
        :param pulumi.Input[_builtins.str] master: Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`. Default: `PROFILE_MASTER`
        :param pulumi.Input[_builtins.str] pattern: The validation pattern to use for the subschema. Must be in form of '.+', or '[\\n\\n]+' if present.'
        :param pulumi.Input[_builtins.str] permissions: Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        :param pulumi.Input[_builtins.bool] required: Whether the subschema is required
        :param pulumi.Input[_builtins.str] title: Subschema title (display name)
        :param pulumi.Input[_builtins.str] type: The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        :param pulumi.Input[_builtins.str] user_type: User type ID. By default, it is `default`
        """
        if index is not None:
            pulumi.set(__self__, "index", index)
        if master is not None:
            pulumi.set(__self__, "master", master)
        if pattern is not None:
            pulumi.set(__self__, "pattern", pattern)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if required is not None:
            pulumi.set(__self__, "required", required)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if user_type is not None:
            pulumi.set(__self__, "user_type", user_type)

    @_builtins.property
    @pulumi.getter
    def index(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Subschema unique string identifier
        """
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "index", value)

    @_builtins.property
    @pulumi.getter
    def master(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`. Default: `PROFILE_MASTER`
        """
        return pulumi.get(self, "master")

    @master.setter
    def master(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "master", value)

    @_builtins.property
    @pulumi.getter
    def pattern(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The validation pattern to use for the subschema. Must be in form of '.+', or '[\\n\\n]+' if present.'
        """
        return pulumi.get(self, "pattern")

    @pattern.setter
    def pattern(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pattern", value)

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "permissions", value)

    @_builtins.property
    @pulumi.getter
    def required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the subschema is required
        """
        return pulumi.get(self, "required")

    @required.setter
    def required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "required", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Subschema title (display name)
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "title", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="userType")
    def user_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User type ID. By default, it is `default`
        """
        return pulumi.get(self, "user_type")

    @user_type.setter
    def user_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_type", value)


@pulumi.type_token("okta:index/userBaseSchemaProperty:UserBaseSchemaProperty")
class UserBaseSchemaProperty(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 index: Optional[pulumi.Input[_builtins.str]] = None,
                 master: Optional[pulumi.Input[_builtins.str]] = None,
                 pattern: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[_builtins.str]] = None,
                 required: Optional[pulumi.Input[_builtins.bool]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 user_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a User Base Schema property. This resource allows you to configure a base user schema property.

        ## IMPORTANT NOTE:

        Based on the [official documentation](https://developer.okta.com/docs/reference/api/schemas/#user-profile-base-subschema)
        base properties can not be modified, except to update permissions, to change the nullability of `firstName` and
        `lastName` (`required` property) or to specify a `pattern` for `login`. Currently, `title` and `type` are required, so
        they should be set to the current values of the base property. This will be fixed in the future releases, as this is
        a breaking change.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.UserBaseSchemaProperty("example",
            index="firstName",
            title="First name",
            type="string",
            required=True,
            master="OKTA",
            user_type=example_okta_user_type["id"])
        ```

        ## Import

        ### User schema property of default user type can be imported via the property index.

        ```sh
        $ pulumi import okta:index/userBaseSchemaProperty:UserBaseSchemaProperty example <property_name>
        ```

        ### User schema property of custom user type can be imported via user type id and property index

        ```sh
        $ pulumi import okta:index/userBaseSchemaProperty:UserBaseSchemaProperty example <user_type_id>.<property name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] index: Subschema unique string identifier
        :param pulumi.Input[_builtins.str] master: Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`. Default: `PROFILE_MASTER`
        :param pulumi.Input[_builtins.str] pattern: The validation pattern to use for the subschema. Must be in form of '.+', or '[\\n\\n]+' if present.'
        :param pulumi.Input[_builtins.str] permissions: Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        :param pulumi.Input[_builtins.bool] required: Whether the subschema is required
        :param pulumi.Input[_builtins.str] title: Subschema title (display name)
        :param pulumi.Input[_builtins.str] type: The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        :param pulumi.Input[_builtins.str] user_type: User type ID. By default, it is `default`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserBaseSchemaPropertyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a User Base Schema property. This resource allows you to configure a base user schema property.

        ## IMPORTANT NOTE:

        Based on the [official documentation](https://developer.okta.com/docs/reference/api/schemas/#user-profile-base-subschema)
        base properties can not be modified, except to update permissions, to change the nullability of `firstName` and
        `lastName` (`required` property) or to specify a `pattern` for `login`. Currently, `title` and `type` are required, so
        they should be set to the current values of the base property. This will be fixed in the future releases, as this is
        a breaking change.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.UserBaseSchemaProperty("example",
            index="firstName",
            title="First name",
            type="string",
            required=True,
            master="OKTA",
            user_type=example_okta_user_type["id"])
        ```

        ## Import

        ### User schema property of default user type can be imported via the property index.

        ```sh
        $ pulumi import okta:index/userBaseSchemaProperty:UserBaseSchemaProperty example <property_name>
        ```

        ### User schema property of custom user type can be imported via user type id and property index

        ```sh
        $ pulumi import okta:index/userBaseSchemaProperty:UserBaseSchemaProperty example <user_type_id>.<property name>
        ```

        :param str resource_name: The name of the resource.
        :param UserBaseSchemaPropertyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserBaseSchemaPropertyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 index: Optional[pulumi.Input[_builtins.str]] = None,
                 master: Optional[pulumi.Input[_builtins.str]] = None,
                 pattern: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[_builtins.str]] = None,
                 required: Optional[pulumi.Input[_builtins.bool]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 user_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserBaseSchemaPropertyArgs.__new__(UserBaseSchemaPropertyArgs)

            if index is None and not opts.urn:
                raise TypeError("Missing required property 'index'")
            __props__.__dict__["index"] = index
            __props__.__dict__["master"] = master
            __props__.__dict__["pattern"] = pattern
            __props__.__dict__["permissions"] = permissions
            __props__.__dict__["required"] = required
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__.__dict__["title"] = title
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["user_type"] = user_type
        super(UserBaseSchemaProperty, __self__).__init__(
            'okta:index/userBaseSchemaProperty:UserBaseSchemaProperty',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            index: Optional[pulumi.Input[_builtins.str]] = None,
            master: Optional[pulumi.Input[_builtins.str]] = None,
            pattern: Optional[pulumi.Input[_builtins.str]] = None,
            permissions: Optional[pulumi.Input[_builtins.str]] = None,
            required: Optional[pulumi.Input[_builtins.bool]] = None,
            title: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            user_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'UserBaseSchemaProperty':
        """
        Get an existing UserBaseSchemaProperty resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] index: Subschema unique string identifier
        :param pulumi.Input[_builtins.str] master: Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`. Default: `PROFILE_MASTER`
        :param pulumi.Input[_builtins.str] pattern: The validation pattern to use for the subschema. Must be in form of '.+', or '[\\n\\n]+' if present.'
        :param pulumi.Input[_builtins.str] permissions: Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        :param pulumi.Input[_builtins.bool] required: Whether the subschema is required
        :param pulumi.Input[_builtins.str] title: Subschema title (display name)
        :param pulumi.Input[_builtins.str] type: The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        :param pulumi.Input[_builtins.str] user_type: User type ID. By default, it is `default`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserBaseSchemaPropertyState.__new__(_UserBaseSchemaPropertyState)

        __props__.__dict__["index"] = index
        __props__.__dict__["master"] = master
        __props__.__dict__["pattern"] = pattern
        __props__.__dict__["permissions"] = permissions
        __props__.__dict__["required"] = required
        __props__.__dict__["title"] = title
        __props__.__dict__["type"] = type
        __props__.__dict__["user_type"] = user_type
        return UserBaseSchemaProperty(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def index(self) -> pulumi.Output[_builtins.str]:
        """
        Subschema unique string identifier
        """
        return pulumi.get(self, "index")

    @_builtins.property
    @pulumi.getter
    def master(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`. Default: `PROFILE_MASTER`
        """
        return pulumi.get(self, "master")

    @_builtins.property
    @pulumi.getter
    def pattern(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The validation pattern to use for the subschema. Must be in form of '.+', or '[\\n\\n]+' if present.'
        """
        return pulumi.get(self, "pattern")

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        """
        return pulumi.get(self, "permissions")

    @_builtins.property
    @pulumi.getter
    def required(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the subschema is required
        """
        return pulumi.get(self, "required")

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Output[_builtins.str]:
        """
        Subschema title (display name)
        """
        return pulumi.get(self, "title")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="userType")
    def user_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        User type ID. By default, it is `default`
        """
        return pulumi.get(self, "user_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetEntitlementBundleResult',
    'AwaitableGetEntitlementBundleResult',
    'get_entitlement_bundle',
    'get_entitlement_bundle_output',
]

@pulumi.output_type
class GetEntitlementBundleResult:
    """
    A collection of values returned by getEntitlementBundle.
    """
    def __init__(__self__, created=None, created_by=None, description=None, entitlements=None, id=None, last_updated=None, last_updated_by=None, name=None, status=None, target=None, target_resource_orn=None):
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if entitlements and not isinstance(entitlements, list):
            raise TypeError("Expected argument 'entitlements' to be a list")
        pulumi.set(__self__, "entitlements", entitlements)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if last_updated_by and not isinstance(last_updated_by, str):
            raise TypeError("Expected argument 'last_updated_by' to be a str")
        pulumi.set(__self__, "last_updated_by", last_updated_by)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if target and not isinstance(target, dict):
            raise TypeError("Expected argument 'target' to be a dict")
        pulumi.set(__self__, "target", target)
        if target_resource_orn and not isinstance(target_resource_orn, str):
            raise TypeError("Expected argument 'target_resource_orn' to be a str")
        pulumi.set(__self__, "target_resource_orn", target_resource_orn)

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        The created timestamp of this resource.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        """
        The ID of the user that created this resource.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of an entitlement property.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def entitlements(self) -> Optional[Sequence['outputs.GetEntitlementBundleEntitlementResult']]:
        """
        List of entitlements in the bundle
        """
        return pulumi.get(self, "entitlements")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        """
        The last updated timestamp of this resource.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> _builtins.str:
        """
        The ID of the user that last updated this resource.
        """
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The display name for an entitlement bundle.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the entitlement bundle.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def target(self) -> Optional['outputs.GetEntitlementBundleTargetResult']:
        """
        Representation of a resource
        """
        return pulumi.get(self, "target")

    @_builtins.property
    @pulumi.getter(name="targetResourceOrn")
    def target_resource_orn(self) -> _builtins.str:
        """
        The ORN of the target resource. Required when updating the entitlement bundle.
        """
        return pulumi.get(self, "target_resource_orn")


class AwaitableGetEntitlementBundleResult(GetEntitlementBundleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEntitlementBundleResult(
            created=self.created,
            created_by=self.created_by,
            description=self.description,
            entitlements=self.entitlements,
            id=self.id,
            last_updated=self.last_updated,
            last_updated_by=self.last_updated_by,
            name=self.name,
            status=self.status,
            target=self.target,
            target_resource_orn=self.target_resource_orn)


def get_entitlement_bundle(entitlements: Optional[Sequence[Union['GetEntitlementBundleEntitlementArgs', 'GetEntitlementBundleEntitlementArgsDict']]] = None,
                           id: Optional[_builtins.str] = None,
                           target: Optional[Union['GetEntitlementBundleTargetArgs', 'GetEntitlementBundleTargetArgsDict']] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEntitlementBundleResult:
    """
    Get the entitlement bundle for the given id.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_entitlement_bundle(id="<entitlement_bundle id>")
    ```


    :param Sequence[Union['GetEntitlementBundleEntitlementArgs', 'GetEntitlementBundleEntitlementArgsDict']] entitlements: List of entitlements in the bundle
    :param _builtins.str id: The ID of this resource.
    :param Union['GetEntitlementBundleTargetArgs', 'GetEntitlementBundleTargetArgsDict'] target: Representation of a resource
    """
    __args__ = dict()
    __args__['entitlements'] = entitlements
    __args__['id'] = id
    __args__['target'] = target
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getEntitlementBundle:getEntitlementBundle', __args__, opts=opts, typ=GetEntitlementBundleResult).value

    return AwaitableGetEntitlementBundleResult(
        created=pulumi.get(__ret__, 'created'),
        created_by=pulumi.get(__ret__, 'created_by'),
        description=pulumi.get(__ret__, 'description'),
        entitlements=pulumi.get(__ret__, 'entitlements'),
        id=pulumi.get(__ret__, 'id'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        last_updated_by=pulumi.get(__ret__, 'last_updated_by'),
        name=pulumi.get(__ret__, 'name'),
        status=pulumi.get(__ret__, 'status'),
        target=pulumi.get(__ret__, 'target'),
        target_resource_orn=pulumi.get(__ret__, 'target_resource_orn'))
def get_entitlement_bundle_output(entitlements: Optional[pulumi.Input[Optional[Sequence[Union['GetEntitlementBundleEntitlementArgs', 'GetEntitlementBundleEntitlementArgsDict']]]]] = None,
                                  id: Optional[pulumi.Input[_builtins.str]] = None,
                                  target: Optional[pulumi.Input[Optional[Union['GetEntitlementBundleTargetArgs', 'GetEntitlementBundleTargetArgsDict']]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEntitlementBundleResult]:
    """
    Get the entitlement bundle for the given id.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_entitlement_bundle(id="<entitlement_bundle id>")
    ```


    :param Sequence[Union['GetEntitlementBundleEntitlementArgs', 'GetEntitlementBundleEntitlementArgsDict']] entitlements: List of entitlements in the bundle
    :param _builtins.str id: The ID of this resource.
    :param Union['GetEntitlementBundleTargetArgs', 'GetEntitlementBundleTargetArgsDict'] target: Representation of a resource
    """
    __args__ = dict()
    __args__['entitlements'] = entitlements
    __args__['id'] = id
    __args__['target'] = target
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getEntitlementBundle:getEntitlementBundle', __args__, opts=opts, typ=GetEntitlementBundleResult)
    return __ret__.apply(lambda __response__: GetEntitlementBundleResult(
        created=pulumi.get(__response__, 'created'),
        created_by=pulumi.get(__response__, 'created_by'),
        description=pulumi.get(__response__, 'description'),
        entitlements=pulumi.get(__response__, 'entitlements'),
        id=pulumi.get(__response__, 'id'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        last_updated_by=pulumi.get(__response__, 'last_updated_by'),
        name=pulumi.get(__response__, 'name'),
        status=pulumi.get(__response__, 'status'),
        target=pulumi.get(__response__, 'target'),
        target_resource_orn=pulumi.get(__response__, 'target_resource_orn')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetServerKeysResult',
    'AwaitableGetServerKeysResult',
    'get_server_keys',
    'get_server_keys_output',
]

@pulumi.output_type
class GetServerKeysResult:
    """
    A collection of values returned by getServerKeys.
    """
    def __init__(__self__, alg=None, auth_server_id=None, e=None, id=None, key_id=None, kid=None, n=None, status=None, use=None):
        if alg and not isinstance(alg, str):
            raise TypeError("Expected argument 'alg' to be a str")
        pulumi.set(__self__, "alg", alg)
        if auth_server_id and not isinstance(auth_server_id, str):
            raise TypeError("Expected argument 'auth_server_id' to be a str")
        pulumi.set(__self__, "auth_server_id", auth_server_id)
        if e and not isinstance(e, str):
            raise TypeError("Expected argument 'e' to be a str")
        pulumi.set(__self__, "e", e)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key_id and not isinstance(key_id, str):
            raise TypeError("Expected argument 'key_id' to be a str")
        pulumi.set(__self__, "key_id", key_id)
        if kid and not isinstance(kid, str):
            raise TypeError("Expected argument 'kid' to be a str")
        pulumi.set(__self__, "kid", kid)
        if n and not isinstance(n, str):
            raise TypeError("Expected argument 'n' to be a str")
        pulumi.set(__self__, "n", n)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if use and not isinstance(use, str):
            raise TypeError("Expected argument 'use' to be a str")
        pulumi.set(__self__, "use", use)

    @_builtins.property
    @pulumi.getter
    def alg(self) -> _builtins.str:
        """
        The algorithm used with the Key. Typically "RS256" for RSA keys.
        """
        return pulumi.get(self, "alg")

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> _builtins.str:
        """
        The ID of the authorization server.
        """
        return pulumi.get(self, "auth_server_id")

    @_builtins.property
    @pulumi.getter
    def e(self) -> _builtins.str:
        """
        RSA key value (public exponent) for Key binding. Typically "AQAB".
        """
        return pulumi.get(self, "e")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="keyId")
    def key_id(self) -> _builtins.str:
        """
        The ID of the certificate key.
        """
        return pulumi.get(self, "key_id")

    @_builtins.property
    @pulumi.getter
    def kid(self) -> _builtins.str:
        """
        Unique identifier for the key (Key ID).
        """
        return pulumi.get(self, "kid")

    @_builtins.property
    @pulumi.getter
    def n(self) -> _builtins.str:
        """
        RSA modulus value that is used by both the public and private keys and provides a link between them.
        """
        return pulumi.get(self, "n")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the key. An ACTIVE key is used to sign tokens issued by the authorization server. Supported values: `ACTIVE`, `NEXT`, or `EXPIRED`. A NEXT key is the next key that the authorization server uses to sign tokens when keys are rotated. The NEXT key might not be listed if it hasn't been generated. An EXPIRED key is the previous key that the authorization server used to sign tokens. The EXPIRED key might not be listed if no key has expired or the expired key was deleted.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def use(self) -> _builtins.str:
        """
        Acceptable use of the key. Typically "sig" for signature operations.
        """
        return pulumi.get(self, "use")


class AwaitableGetServerKeysResult(GetServerKeysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerKeysResult(
            alg=self.alg,
            auth_server_id=self.auth_server_id,
            e=self.e,
            id=self.id,
            key_id=self.key_id,
            kid=self.kid,
            n=self.n,
            status=self.status,
            use=self.use)


def get_server_keys(auth_server_id: Optional[_builtins.str] = None,
                    key_id: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerKeysResult:
    """
    Get a specific authorization server credential key from Okta. Authorization server keys are JSON Web Keys (JWK) used for signing tokens issued by the authorization server.

    This data source allows you to retrieve information about a specific key used by an authorization server for token signing operations.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.auth.get_server_keys(auth_server_id="aus123456789abcdefgh",
        key_id="abcdefghijk0123456789")
    ```

    ## Notes

    - To find available key IDs for an authorization server, you can use the Okta Admin Console or make a direct API call to `/api/v1/authorizationServers/{authServerId}/credentials/keys`
    - The key ID (`kid`) is automatically generated by Okta and is unique within the authorization server
    - This data source is useful for retrieving key information for verification purposes or to reference in other configurations


    :param _builtins.str auth_server_id: The ID of the authorization server.
    :param _builtins.str key_id: The ID of the certificate key.
    """
    __args__ = dict()
    __args__['authServerId'] = auth_server_id
    __args__['keyId'] = key_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:auth/getServerKeys:getServerKeys', __args__, opts=opts, typ=GetServerKeysResult).value

    return AwaitableGetServerKeysResult(
        alg=pulumi.get(__ret__, 'alg'),
        auth_server_id=pulumi.get(__ret__, 'auth_server_id'),
        e=pulumi.get(__ret__, 'e'),
        id=pulumi.get(__ret__, 'id'),
        key_id=pulumi.get(__ret__, 'key_id'),
        kid=pulumi.get(__ret__, 'kid'),
        n=pulumi.get(__ret__, 'n'),
        status=pulumi.get(__ret__, 'status'),
        use=pulumi.get(__ret__, 'use'))
def get_server_keys_output(auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                           key_id: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServerKeysResult]:
    """
    Get a specific authorization server credential key from Okta. Authorization server keys are JSON Web Keys (JWK) used for signing tokens issued by the authorization server.

    This data source allows you to retrieve information about a specific key used by an authorization server for token signing operations.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.auth.get_server_keys(auth_server_id="aus123456789abcdefgh",
        key_id="abcdefghijk0123456789")
    ```

    ## Notes

    - To find available key IDs for an authorization server, you can use the Okta Admin Console or make a direct API call to `/api/v1/authorizationServers/{authServerId}/credentials/keys`
    - The key ID (`kid`) is automatically generated by Okta and is unique within the authorization server
    - This data source is useful for retrieving key information for verification purposes or to reference in other configurations


    :param _builtins.str auth_server_id: The ID of the authorization server.
    :param _builtins.str key_id: The ID of the certificate key.
    """
    __args__ = dict()
    __args__['authServerId'] = auth_server_id
    __args__['keyId'] = key_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:auth/getServerKeys:getServerKeys', __args__, opts=opts, typ=GetServerKeysResult)
    return __ret__.apply(lambda __response__: GetServerKeysResult(
        alg=pulumi.get(__response__, 'alg'),
        auth_server_id=pulumi.get(__response__, 'auth_server_id'),
        e=pulumi.get(__response__, 'e'),
        id=pulumi.get(__response__, 'id'),
        key_id=pulumi.get(__response__, 'key_id'),
        kid=pulumi.get(__response__, 'kid'),
        n=pulumi.get(__response__, 'n'),
        status=pulumi.get(__response__, 'status'),
        use=pulumi.get(__response__, 'use')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAuthServerClaimResult',
    'AwaitableGetAuthServerClaimResult',
    'get_auth_server_claim',
    'get_auth_server_claim_output',
]

@pulumi.output_type
class GetAuthServerClaimResult:
    """
    A collection of values returned by getAuthServerClaim.
    """
    def __init__(__self__, always_include_in_token=None, auth_server_id=None, claim_type=None, id=None, name=None, scopes=None, status=None, value=None, value_type=None):
        if always_include_in_token and not isinstance(always_include_in_token, bool):
            raise TypeError("Expected argument 'always_include_in_token' to be a bool")
        pulumi.set(__self__, "always_include_in_token", always_include_in_token)
        if auth_server_id and not isinstance(auth_server_id, str):
            raise TypeError("Expected argument 'auth_server_id' to be a str")
        pulumi.set(__self__, "auth_server_id", auth_server_id)
        if claim_type and not isinstance(claim_type, str):
            raise TypeError("Expected argument 'claim_type' to be a str")
        pulumi.set(__self__, "claim_type", claim_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if scopes and not isinstance(scopes, list):
            raise TypeError("Expected argument 'scopes' to be a list")
        pulumi.set(__self__, "scopes", scopes)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if value and not isinstance(value, str):
            raise TypeError("Expected argument 'value' to be a str")
        pulumi.set(__self__, "value", value)
        if value_type and not isinstance(value_type, str):
            raise TypeError("Expected argument 'value_type' to be a str")
        pulumi.set(__self__, "value_type", value_type)

    @_builtins.property
    @pulumi.getter(name="alwaysIncludeInToken")
    def always_include_in_token(self) -> _builtins.bool:
        """
        Specifies whether to include Claims in the token.
        """
        return pulumi.get(self, "always_include_in_token")

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> _builtins.str:
        """
        Auth server ID
        """
        return pulumi.get(self, "auth_server_id")

    @_builtins.property
    @pulumi.getter(name="claimType")
    def claim_type(self) -> _builtins.str:
        """
        Specifies whether the Claim is for an access token (`RESOURCE`) or ID token (`IDENTITY`).
        """
        return pulumi.get(self, "claim_type")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Name of the claim. Conflicts with `name`.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the claim. Conflicts with `id`.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Sequence[_builtins.str]:
        """
        Auth server claim list of scopes
        """
        return pulumi.get(self, "scopes")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Status of the claim.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        """
        Value of the claim.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter(name="valueType")
    def value_type(self) -> _builtins.str:
        """
        Specifies whether the Claim is an Okta EL expression (`EXPRESSION`), a set of groups (`GROUPS`), or a system claim (`SYSTEM`)
        """
        return pulumi.get(self, "value_type")


class AwaitableGetAuthServerClaimResult(GetAuthServerClaimResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuthServerClaimResult(
            always_include_in_token=self.always_include_in_token,
            auth_server_id=self.auth_server_id,
            claim_type=self.claim_type,
            id=self.id,
            name=self.name,
            scopes=self.scopes,
            status=self.status,
            value=self.value,
            value_type=self.value_type)


def get_auth_server_claim(auth_server_id: Optional[_builtins.str] = None,
                          id: Optional[_builtins.str] = None,
                          name: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuthServerClaimResult:
    """
    Get authorization server claim from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_auth_server_claim(auth_server_id="default",
        name="birthdate")
    ```


    :param _builtins.str auth_server_id: Auth server ID
    :param _builtins.str id: Name of the claim. Conflicts with `name`.
    :param _builtins.str name: Name of the claim. Conflicts with `id`.
    """
    __args__ = dict()
    __args__['authServerId'] = auth_server_id
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getAuthServerClaim:getAuthServerClaim', __args__, opts=opts, typ=GetAuthServerClaimResult).value

    return AwaitableGetAuthServerClaimResult(
        always_include_in_token=pulumi.get(__ret__, 'always_include_in_token'),
        auth_server_id=pulumi.get(__ret__, 'auth_server_id'),
        claim_type=pulumi.get(__ret__, 'claim_type'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        scopes=pulumi.get(__ret__, 'scopes'),
        status=pulumi.get(__ret__, 'status'),
        value=pulumi.get(__ret__, 'value'),
        value_type=pulumi.get(__ret__, 'value_type'))
def get_auth_server_claim_output(auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                                 id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAuthServerClaimResult]:
    """
    Get authorization server claim from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_auth_server_claim(auth_server_id="default",
        name="birthdate")
    ```


    :param _builtins.str auth_server_id: Auth server ID
    :param _builtins.str id: Name of the claim. Conflicts with `name`.
    :param _builtins.str name: Name of the claim. Conflicts with `id`.
    """
    __args__ = dict()
    __args__['authServerId'] = auth_server_id
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getAuthServerClaim:getAuthServerClaim', __args__, opts=opts, typ=GetAuthServerClaimResult)
    return __ret__.apply(lambda __response__: GetAuthServerClaimResult(
        always_include_in_token=pulumi.get(__response__, 'always_include_in_token'),
        auth_server_id=pulumi.get(__response__, 'auth_server_id'),
        claim_type=pulumi.get(__response__, 'claim_type'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        scopes=pulumi.get(__response__, 'scopes'),
        status=pulumi.get(__response__, 'status'),
        value=pulumi.get(__response__, 'value'),
        value_type=pulumi.get(__response__, 'value_type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'UserPasswordHashArgs',
    'UserPasswordHashArgsDict',
    'GetUserSearchArgs',
    'GetUserSearchArgsDict',
    'GetUsersSearchArgs',
    'GetUsersSearchArgsDict',
]

MYPY = False

if not MYPY:
    class UserPasswordHashArgsDict(TypedDict):
        algorithm: pulumi.Input[_builtins.str]
        """
        The algorithm used to generate the hash using the password
        """
        value: pulumi.Input[_builtins.str]
        """
        For SHA-512, SHA-256, SHA-1, MD5, This is the actual base64-encoded hash of the password (and salt, if used). This is the Base64 encoded value of the SHA-512/SHA-256/SHA-1/MD5 digest that was computed by either pre-fixing or post-fixing the salt to the password, depending on the saltOrder. If a salt was not used in the source system, then this should just be the the Base64 encoded value of the password's SHA-512/SHA-256/SHA-1/MD5 digest. For BCRYPT, This is the actual radix64-encoded hashed password.
        """
        salt: NotRequired[pulumi.Input[_builtins.str]]
        """
        Only required for salted hashes
        """
        salt_order: NotRequired[pulumi.Input[_builtins.str]]
        """
        Specifies whether salt was pre- or postfixed to the password before hashing
        """
        work_factor: NotRequired[pulumi.Input[_builtins.int]]
        """
        Governs the strength of the hash and the time required to compute it. Only required for BCRYPT algorithm
        """
elif False:
    UserPasswordHashArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UserPasswordHashArgs:
    def __init__(__self__, *,
                 algorithm: pulumi.Input[_builtins.str],
                 value: pulumi.Input[_builtins.str],
                 salt: Optional[pulumi.Input[_builtins.str]] = None,
                 salt_order: Optional[pulumi.Input[_builtins.str]] = None,
                 work_factor: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] algorithm: The algorithm used to generate the hash using the password
        :param pulumi.Input[_builtins.str] value: For SHA-512, SHA-256, SHA-1, MD5, This is the actual base64-encoded hash of the password (and salt, if used). This is the Base64 encoded value of the SHA-512/SHA-256/SHA-1/MD5 digest that was computed by either pre-fixing or post-fixing the salt to the password, depending on the saltOrder. If a salt was not used in the source system, then this should just be the the Base64 encoded value of the password's SHA-512/SHA-256/SHA-1/MD5 digest. For BCRYPT, This is the actual radix64-encoded hashed password.
        :param pulumi.Input[_builtins.str] salt: Only required for salted hashes
        :param pulumi.Input[_builtins.str] salt_order: Specifies whether salt was pre- or postfixed to the password before hashing
        :param pulumi.Input[_builtins.int] work_factor: Governs the strength of the hash and the time required to compute it. Only required for BCRYPT algorithm
        """
        pulumi.set(__self__, "algorithm", algorithm)
        pulumi.set(__self__, "value", value)
        if salt is not None:
            pulumi.set(__self__, "salt", salt)
        if salt_order is not None:
            pulumi.set(__self__, "salt_order", salt_order)
        if work_factor is not None:
            pulumi.set(__self__, "work_factor", work_factor)

    @_builtins.property
    @pulumi.getter
    def algorithm(self) -> pulumi.Input[_builtins.str]:
        """
        The algorithm used to generate the hash using the password
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "algorithm", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Input[_builtins.str]:
        """
        For SHA-512, SHA-256, SHA-1, MD5, This is the actual base64-encoded hash of the password (and salt, if used). This is the Base64 encoded value of the SHA-512/SHA-256/SHA-1/MD5 digest that was computed by either pre-fixing or post-fixing the salt to the password, depending on the saltOrder. If a salt was not used in the source system, then this should just be the the Base64 encoded value of the password's SHA-512/SHA-256/SHA-1/MD5 digest. For BCRYPT, This is the actual radix64-encoded hashed password.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter
    def salt(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Only required for salted hashes
        """
        return pulumi.get(self, "salt")

    @salt.setter
    def salt(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "salt", value)

    @_builtins.property
    @pulumi.getter(name="saltOrder")
    def salt_order(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether salt was pre- or postfixed to the password before hashing
        """
        return pulumi.get(self, "salt_order")

    @salt_order.setter
    def salt_order(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "salt_order", value)

    @_builtins.property
    @pulumi.getter(name="workFactor")
    def work_factor(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Governs the strength of the hash and the time required to compute it. Only required for BCRYPT algorithm
        """
        return pulumi.get(self, "work_factor")

    @work_factor.setter
    def work_factor(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "work_factor", value)


if not MYPY:
    class GetUserSearchArgsDict(TypedDict):
        comparison: NotRequired[_builtins.str]
        expression: NotRequired[_builtins.str]
        """
        A raw search expression string. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        """
        name: NotRequired[_builtins.str]
        """
        Property name to search for. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        """
        value: NotRequired[_builtins.str]
elif False:
    GetUserSearchArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetUserSearchArgs:
    def __init__(__self__, *,
                 comparison: Optional[_builtins.str] = None,
                 expression: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None,
                 value: Optional[_builtins.str] = None):
        """
        :param _builtins.str expression: A raw search expression string. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        :param _builtins.str name: Property name to search for. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        """
        if comparison is not None:
            pulumi.set(__self__, "comparison", comparison)
        if expression is not None:
            pulumi.set(__self__, "expression", expression)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def comparison(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "comparison")

    @comparison.setter
    def comparison(self, value: Optional[_builtins.str]):
        pulumi.set(self, "comparison", value)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> Optional[_builtins.str]:
        """
        A raw search expression string. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: Optional[_builtins.str]):
        pulumi.set(self, "expression", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Property name to search for. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[_builtins.str]):
        pulumi.set(self, "value", value)


if not MYPY:
    class GetUsersSearchArgsDict(TypedDict):
        comparison: NotRequired[_builtins.str]
        expression: NotRequired[_builtins.str]
        """
        A raw search expression string. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        """
        name: NotRequired[_builtins.str]
        """
        Property name to search for. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        """
        value: NotRequired[_builtins.str]
elif False:
    GetUsersSearchArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetUsersSearchArgs:
    def __init__(__self__, *,
                 comparison: Optional[_builtins.str] = None,
                 expression: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None,
                 value: Optional[_builtins.str] = None):
        """
        :param _builtins.str expression: A raw search expression string. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        :param _builtins.str name: Property name to search for. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        """
        if comparison is not None:
            pulumi.set(__self__, "comparison", comparison)
        if expression is not None:
            pulumi.set(__self__, "expression", expression)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def comparison(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "comparison")

    @comparison.setter
    def comparison(self, value: Optional[_builtins.str]):
        pulumi.set(self, "comparison", value)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> Optional[_builtins.str]:
        """
        A raw search expression string. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: Optional[_builtins.str]):
        pulumi.set(self, "expression", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Property name to search for. This requires the search feature be on. Please see Okta documentation on their filter API for users. https://developer.okta.com/docs/api/resources/users#list-users-with-search
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[_builtins.str]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RequestSettingResourceArgs', 'RequestSettingResource']

@pulumi.input_type
class RequestSettingResourceArgs:
    def __init__(__self__, *,
                 id_property: pulumi.Input[_builtins.str],
                 request_on_behalf_of_settings: Optional[pulumi.Input['RequestSettingResourceRequestOnBehalfOfSettingsArgs']] = None,
                 risk_settings: Optional[pulumi.Input['RequestSettingResourceRiskSettingsArgs']] = None):
        """
        The set of arguments for constructing a RequestSettingResource resource.
        :param pulumi.Input[_builtins.str] id_property: The id of the resource in Okta ID format.
        :param pulumi.Input['RequestSettingResourceRequestOnBehalfOfSettingsArgs'] request_on_behalf_of_settings: Specifies if and for whom a requester may request the resource for.
        :param pulumi.Input['RequestSettingResourceRiskSettingsArgs'] risk_settings: Risk settings for the resource.
        """
        pulumi.set(__self__, "id_property", id_property)
        if request_on_behalf_of_settings is not None:
            pulumi.set(__self__, "request_on_behalf_of_settings", request_on_behalf_of_settings)
        if risk_settings is not None:
            pulumi.set(__self__, "risk_settings", risk_settings)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter(name="requestOnBehalfOfSettings")
    def request_on_behalf_of_settings(self) -> Optional[pulumi.Input['RequestSettingResourceRequestOnBehalfOfSettingsArgs']]:
        """
        Specifies if and for whom a requester may request the resource for.
        """
        return pulumi.get(self, "request_on_behalf_of_settings")

    @request_on_behalf_of_settings.setter
    def request_on_behalf_of_settings(self, value: Optional[pulumi.Input['RequestSettingResourceRequestOnBehalfOfSettingsArgs']]):
        pulumi.set(self, "request_on_behalf_of_settings", value)

    @_builtins.property
    @pulumi.getter(name="riskSettings")
    def risk_settings(self) -> Optional[pulumi.Input['RequestSettingResourceRiskSettingsArgs']]:
        """
        Risk settings for the resource.
        """
        return pulumi.get(self, "risk_settings")

    @risk_settings.setter
    def risk_settings(self, value: Optional[pulumi.Input['RequestSettingResourceRiskSettingsArgs']]):
        pulumi.set(self, "risk_settings", value)


@pulumi.input_type
class _RequestSettingResourceState:
    def __init__(__self__, *,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 request_on_behalf_of_settings: Optional[pulumi.Input['RequestSettingResourceRequestOnBehalfOfSettingsArgs']] = None,
                 risk_settings: Optional[pulumi.Input['RequestSettingResourceRiskSettingsArgs']] = None):
        """
        Input properties used for looking up and filtering RequestSettingResource resources.
        :param pulumi.Input[_builtins.str] id_property: The id of the resource in Okta ID format.
        :param pulumi.Input['RequestSettingResourceRequestOnBehalfOfSettingsArgs'] request_on_behalf_of_settings: Specifies if and for whom a requester may request the resource for.
        :param pulumi.Input['RequestSettingResourceRiskSettingsArgs'] risk_settings: Risk settings for the resource.
        """
        if id_property is not None:
            pulumi.set(__self__, "id_property", id_property)
        if request_on_behalf_of_settings is not None:
            pulumi.set(__self__, "request_on_behalf_of_settings", request_on_behalf_of_settings)
        if risk_settings is not None:
            pulumi.set(__self__, "risk_settings", risk_settings)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter(name="requestOnBehalfOfSettings")
    def request_on_behalf_of_settings(self) -> Optional[pulumi.Input['RequestSettingResourceRequestOnBehalfOfSettingsArgs']]:
        """
        Specifies if and for whom a requester may request the resource for.
        """
        return pulumi.get(self, "request_on_behalf_of_settings")

    @request_on_behalf_of_settings.setter
    def request_on_behalf_of_settings(self, value: Optional[pulumi.Input['RequestSettingResourceRequestOnBehalfOfSettingsArgs']]):
        pulumi.set(self, "request_on_behalf_of_settings", value)

    @_builtins.property
    @pulumi.getter(name="riskSettings")
    def risk_settings(self) -> Optional[pulumi.Input['RequestSettingResourceRiskSettingsArgs']]:
        """
        Risk settings for the resource.
        """
        return pulumi.get(self, "risk_settings")

    @risk_settings.setter
    def risk_settings(self, value: Optional[pulumi.Input['RequestSettingResourceRiskSettingsArgs']]):
        pulumi.set(self, "risk_settings", value)


@pulumi.type_token("okta:index/requestSettingResource:RequestSettingResource")
class RequestSettingResource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 request_on_behalf_of_settings: Optional[pulumi.Input[Union['RequestSettingResourceRequestOnBehalfOfSettingsArgs', 'RequestSettingResourceRequestOnBehalfOfSettingsArgsDict']]] = None,
                 risk_settings: Optional[pulumi.Input[Union['RequestSettingResourceRiskSettingsArgs', 'RequestSettingResourceRiskSettingsArgsDict']]] = None,
                 __props__=None):
        """
        Manages request settings. This resource allows you to read and configure an Okta [request-setting](https://developer.okta.com/docs/api/iga/openapi/governance.requests.admin.v2/tag/Request-Settings/#tag/Request-Settings/operation/getRequestSettingsV2).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.RequestSettingResource("test",
            resource_id="<resource_id>",
            risk_settings={
                "default_setting": {
                    "request_submission_type": "ALLOWED_WITH_OVERRIDES",
                    "approval_sequence_id": "<approval_sequence_id>",
                },
            },
            request_on_behalf_of_settings={
                "allowed": True,
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/requestSettingResource:RequestSettingResource example "<resource_id>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] id_property: The id of the resource in Okta ID format.
        :param pulumi.Input[Union['RequestSettingResourceRequestOnBehalfOfSettingsArgs', 'RequestSettingResourceRequestOnBehalfOfSettingsArgsDict']] request_on_behalf_of_settings: Specifies if and for whom a requester may request the resource for.
        :param pulumi.Input[Union['RequestSettingResourceRiskSettingsArgs', 'RequestSettingResourceRiskSettingsArgsDict']] risk_settings: Risk settings for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RequestSettingResourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages request settings. This resource allows you to read and configure an Okta [request-setting](https://developer.okta.com/docs/api/iga/openapi/governance.requests.admin.v2/tag/Request-Settings/#tag/Request-Settings/operation/getRequestSettingsV2).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.RequestSettingResource("test",
            resource_id="<resource_id>",
            risk_settings={
                "default_setting": {
                    "request_submission_type": "ALLOWED_WITH_OVERRIDES",
                    "approval_sequence_id": "<approval_sequence_id>",
                },
            },
            request_on_behalf_of_settings={
                "allowed": True,
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/requestSettingResource:RequestSettingResource example "<resource_id>"
        ```

        :param str resource_name: The name of the resource.
        :param RequestSettingResourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RequestSettingResourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 request_on_behalf_of_settings: Optional[pulumi.Input[Union['RequestSettingResourceRequestOnBehalfOfSettingsArgs', 'RequestSettingResourceRequestOnBehalfOfSettingsArgsDict']]] = None,
                 risk_settings: Optional[pulumi.Input[Union['RequestSettingResourceRiskSettingsArgs', 'RequestSettingResourceRiskSettingsArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RequestSettingResourceArgs.__new__(RequestSettingResourceArgs)

            if id_property is None and not opts.urn:
                raise TypeError("Missing required property 'id_property'")
            __props__.__dict__["id_property"] = id_property
            __props__.__dict__["request_on_behalf_of_settings"] = request_on_behalf_of_settings
            __props__.__dict__["risk_settings"] = risk_settings
        super(RequestSettingResource, __self__).__init__(
            'okta:index/requestSettingResource:RequestSettingResource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            id_property: Optional[pulumi.Input[_builtins.str]] = None,
            request_on_behalf_of_settings: Optional[pulumi.Input[Union['RequestSettingResourceRequestOnBehalfOfSettingsArgs', 'RequestSettingResourceRequestOnBehalfOfSettingsArgsDict']]] = None,
            risk_settings: Optional[pulumi.Input[Union['RequestSettingResourceRiskSettingsArgs', 'RequestSettingResourceRiskSettingsArgsDict']]] = None) -> 'RequestSettingResource':
        """
        Get an existing RequestSettingResource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] id_property: The id of the resource in Okta ID format.
        :param pulumi.Input[Union['RequestSettingResourceRequestOnBehalfOfSettingsArgs', 'RequestSettingResourceRequestOnBehalfOfSettingsArgsDict']] request_on_behalf_of_settings: Specifies if and for whom a requester may request the resource for.
        :param pulumi.Input[Union['RequestSettingResourceRiskSettingsArgs', 'RequestSettingResourceRiskSettingsArgsDict']] risk_settings: Risk settings for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RequestSettingResourceState.__new__(_RequestSettingResourceState)

        __props__.__dict__["id_property"] = id_property
        __props__.__dict__["request_on_behalf_of_settings"] = request_on_behalf_of_settings
        __props__.__dict__["risk_settings"] = risk_settings
        return RequestSettingResource(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "id_property")

    @_builtins.property
    @pulumi.getter(name="requestOnBehalfOfSettings")
    def request_on_behalf_of_settings(self) -> pulumi.Output[Optional['outputs.RequestSettingResourceRequestOnBehalfOfSettings']]:
        """
        Specifies if and for whom a requester may request the resource for.
        """
        return pulumi.get(self, "request_on_behalf_of_settings")

    @_builtins.property
    @pulumi.getter(name="riskSettings")
    def risk_settings(self) -> pulumi.Output[Optional['outputs.RequestSettingResourceRiskSettings']]:
        """
        Risk settings for the resource.
        """
        return pulumi.get(self, "risk_settings")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UiSchemaArgs', 'UiSchema']

@pulumi.input_type
class UiSchemaArgs:
    def __init__(__self__, *,
                 ui_schema: Optional[pulumi.Input['UiSchemaUiSchemaArgs']] = None):
        """
        The set of arguments for constructing a UiSchema resource.
        :param pulumi.Input['UiSchemaUiSchemaArgs'] ui_schema: Properties of the UI schema.
        """
        if ui_schema is not None:
            pulumi.set(__self__, "ui_schema", ui_schema)

    @_builtins.property
    @pulumi.getter(name="uiSchema")
    def ui_schema(self) -> Optional[pulumi.Input['UiSchemaUiSchemaArgs']]:
        """
        Properties of the UI schema.
        """
        return pulumi.get(self, "ui_schema")

    @ui_schema.setter
    def ui_schema(self, value: Optional[pulumi.Input['UiSchemaUiSchemaArgs']]):
        pulumi.set(self, "ui_schema", value)


@pulumi.input_type
class _UiSchemaState:
    def __init__(__self__, *,
                 ui_schema: Optional[pulumi.Input['UiSchemaUiSchemaArgs']] = None):
        """
        Input properties used for looking up and filtering UiSchema resources.
        :param pulumi.Input['UiSchemaUiSchemaArgs'] ui_schema: Properties of the UI schema.
        """
        if ui_schema is not None:
            pulumi.set(__self__, "ui_schema", ui_schema)

    @_builtins.property
    @pulumi.getter(name="uiSchema")
    def ui_schema(self) -> Optional[pulumi.Input['UiSchemaUiSchemaArgs']]:
        """
        Properties of the UI schema.
        """
        return pulumi.get(self, "ui_schema")

    @ui_schema.setter
    def ui_schema(self, value: Optional[pulumi.Input['UiSchemaUiSchemaArgs']]):
        pulumi.set(self, "ui_schema", value)


@pulumi.type_token("okta:index/uiSchema:UiSchema")
class UiSchema(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ui_schema: Optional[pulumi.Input[Union['UiSchemaUiSchemaArgs', 'UiSchemaUiSchemaArgsDict']]] = None,
                 __props__=None):
        """
        Manages UI Schema. This resource allows you to create and configure an Okta [UI Schema](https://developer.okta.com/docs/api/openapi/okta-management/management/tag/UISchema/#tag/UISchema) for form layouts and controls.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.UiSchema("example", ui_schema={
            "button_label": "submit",
            "type": "Group",
            "elements": [{
                "scope": "#/properties/lastName",
            }],
        })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/uiSchema:UiSchema example <ui_schema_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['UiSchemaUiSchemaArgs', 'UiSchemaUiSchemaArgsDict']] ui_schema: Properties of the UI schema.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[UiSchemaArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages UI Schema. This resource allows you to create and configure an Okta [UI Schema](https://developer.okta.com/docs/api/openapi/okta-management/management/tag/UISchema/#tag/UISchema) for form layouts and controls.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.UiSchema("example", ui_schema={
            "button_label": "submit",
            "type": "Group",
            "elements": [{
                "scope": "#/properties/lastName",
            }],
        })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/uiSchema:UiSchema example <ui_schema_id>
        ```

        :param str resource_name: The name of the resource.
        :param UiSchemaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UiSchemaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ui_schema: Optional[pulumi.Input[Union['UiSchemaUiSchemaArgs', 'UiSchemaUiSchemaArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UiSchemaArgs.__new__(UiSchemaArgs)

            __props__.__dict__["ui_schema"] = ui_schema
        super(UiSchema, __self__).__init__(
            'okta:index/uiSchema:UiSchema',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ui_schema: Optional[pulumi.Input[Union['UiSchemaUiSchemaArgs', 'UiSchemaUiSchemaArgsDict']]] = None) -> 'UiSchema':
        """
        Get an existing UiSchema resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['UiSchemaUiSchemaArgs', 'UiSchemaUiSchemaArgsDict']] ui_schema: Properties of the UI schema.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UiSchemaState.__new__(_UiSchemaState)

        __props__.__dict__["ui_schema"] = ui_schema
        return UiSchema(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="uiSchema")
    def ui_schema(self) -> pulumi.Output[Optional['outputs.UiSchemaUiSchema']]:
        """
        Properties of the UI schema.
        """
        return pulumi.get(self, "ui_schema")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetFeaturesResult',
    'AwaitableGetFeaturesResult',
    'get_features',
    'get_features_output',
]

@pulumi.output_type
class GetFeaturesResult:
    """
    A collection of values returned by getFeatures.
    """
    def __init__(__self__, features=None, id=None, label=None, substring=None):
        if features and not isinstance(features, list):
            raise TypeError("Expected argument 'features' to be a list")
        pulumi.set(__self__, "features", features)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if substring and not isinstance(substring, str):
            raise TypeError("Expected argument 'substring' to be a str")
        pulumi.set(__self__, "substring", substring)

    @_builtins.property
    @pulumi.getter
    def features(self) -> Sequence['outputs.GetFeaturesFeatureResult']:
        """
        List of `Feature` belonging to the organization
        """
        return pulumi.get(self, "features")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Generated ID
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def label(self) -> Optional[_builtins.str]:
        """
        Searches for features whose label or name property matches this value exactly. Case sensitive
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def substring(self) -> Optional[_builtins.str]:
        """
        Searches for features whose label or name property substring match this value. Case sensitive
        """
        return pulumi.get(self, "substring")


class AwaitableGetFeaturesResult(GetFeaturesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFeaturesResult(
            features=self.features,
            id=self.id,
            label=self.label,
            substring=self.substring)


def get_features(label: Optional[_builtins.str] = None,
                 substring: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFeaturesResult:
    """
    Get a list of features from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_features(label="Android Device Trust")
    ```


    :param _builtins.str label: Searches for features whose label or name property matches this value exactly. Case sensitive
    :param _builtins.str substring: Searches for features whose label or name property substring match this value. Case sensitive
    """
    __args__ = dict()
    __args__['label'] = label
    __args__['substring'] = substring
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getFeatures:getFeatures', __args__, opts=opts, typ=GetFeaturesResult).value

    return AwaitableGetFeaturesResult(
        features=pulumi.get(__ret__, 'features'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        substring=pulumi.get(__ret__, 'substring'))
def get_features_output(label: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        substring: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFeaturesResult]:
    """
    Get a list of features from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_features(label="Android Device Trust")
    ```


    :param _builtins.str label: Searches for features whose label or name property matches this value exactly. Case sensitive
    :param _builtins.str substring: Searches for features whose label or name property substring match this value. Case sensitive
    """
    __args__ = dict()
    __args__['label'] = label
    __args__['substring'] = substring
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getFeatures:getFeatures', __args__, opts=opts, typ=GetFeaturesResult)
    return __ret__.apply(lambda __response__: GetFeaturesResult(
        features=pulumi.get(__response__, 'features'),
        id=pulumi.get(__response__, 'id'),
        label=pulumi.get(__response__, 'label'),
        substring=pulumi.get(__response__, 'substring')))
